from urllib import parse
import urllib,pygame,os
import contextlib
import wave
import urllib.request
import requests,json
import time
from os import path
from urllib.request import urlopen
from urllib.parse import urlencode
from urllib.parse import quote_plus
import hashlib
import random
import base64
import json,time,socket
speaker=1
ak=urllib.request.urlopen("http://www.asunc.cn/ak.txt").read().decode("utf-8")
ak=json.loads(ak)['ak']
class Alsoai():
    def __init__(self):
                self.availble = True
    def get_ipaddress(self,ip, getpoint=False):
        if self.availble!=True:
            return -2
        else:
            if ip.count(".") != 3:
                return -1
            else:
                url = 'http://api.map.baidu.com/location/ip?ak=' + ak + '&ip=' + urllib.parse.quote(ip) + '&coor=bd09ll'
                address = urllib.request.urlopen(url).read().decode("utf-8")
                if True:
                    address = json.loads(address)
                    if address['status'] == 0:
                        if getpoint==True:
                            content = address['content']
                            addrpoint = content['point']
                            return content['address'], addrpoint['x'], addrpoint['y']
                        else:
                            content = address['content']
                            return content['address']

                    else:
                        return -1
    def get_traffic(self,road,city):
        if self.availble != True:
            return -2
        else:
            url='http://api.map.baidu.com/traffic/v1/road?road_name='+urllib.parse.quote(road)+'&city='+urllib.parse.quote(city)+'&ak='+ak
            address = urllib.request.urlopen(url).read().decode("utf-8")
            address = json.loads(address)
            if address['status']==0:
                return address['description']
            else:
                return -1
    def makevoice(self,text, filename,mode=1,speed=40):
        if self.availble != True:
            return -2
        else:
            def getReqSign(params, key):
                dict_kl = sorted(params)
                s = ''
                for k in dict_kl:
                    v = params[k]
                    if v != '':
                        v0 = str(quote_plus(str(v)))
                        s = s + k + '=' + v0 + '&'
                s = s + 'app_key=' + key;
                m = hashlib.md5()
                m.update(s.encode("utf8"))
                sign = m.hexdigest()
                sign = sign.upper()
                return sign
            app=json.loads(urlopen("http://www.asunc.cn/ten.txt").read().decode("utf-8"))
            appid = app['appid']
            appkey = app['appkey']
            url = 'https://api.ai.qq.com/fcgi-bin/aai/aai_tts'
            time_s = int(time.time())
            m = hashlib.md5()
            m.update(str(time_s).encode("utf8"))
            nonce_s = m.hexdigest()
            nonce_s = nonce_s[0:random.randint(1, 31)]
            vmv='1'
            filename=str(filename)
            text=str(text)
            if filename[len(filename)-4]=='.':
                if filename[len(filename)-3]=='p' or filename[len(filename)-3]=='P':
                    wmv='1'
                elif filename[len(filename)-3]=='w' or filename[len(filename)-3]=='W':
                    wmv='2'
                elif filename[len(filename)-3]=='m' or filename[len(filename)-3]=='M':
                    wmv='3'

            params = {'app_id': appid,
                      'speaker': mode,
                      'format': wmv,
                      'volume': '0',
                      'speed': speed * 2,
                      'text': text,
                      'aht': '0',
                      'apc': '58',
                      'time_stamp': time_s,
                      'nonce_str': nonce_s,
                      'sign': ''
                      }
            params['sign'] = getReqSign(params, appkey)
            s = urlencode(params)
            res = urlopen(url, s.encode())  # 网络请求
            res_str = res.read().decode()
            res_dict = eval(res_str)

            if res_dict['ret'] == 0:
                res_data = res_dict['data']
                res_data_format = res_data['format']
                res_data_speech = res_data['speech']
                res_data_md5sum = res_data['md5sum']
                filepath = path.dirname(__file__)  # 目录
                file = '/wav01.wav'
                base64_data = res_data_speech
                ori_image_data = base64.b64decode(base64_data)
                fout = open(filename, 'wb')
                fout.write(ori_image_data)
                fout.close()
                return res_dict['ret']
            else:
                return -1
    def speak(self,text,mode=1,speed=40):
        if self.availble != True:
            return -2
        else:
            def getReqSign(params, key):
                dict_kl = sorted(params)
                s = ''
                for k in dict_kl:
                    v = params[k]
                    if v != '':
                        v0 = str(quote_plus(str(v)))
                        s = s + k + '=' + v0 + '&'
                s = s + 'app_key=' + key;
                m = hashlib.md5()
                m.update(s.encode("utf8"))
                sign = m.hexdigest()
                sign = sign.upper()
                return sign
            app=json.loads(urlopen("http://www.asunc.cn/ten.txt").read().decode("utf-8"))
            appid = app['appid']
            appkey = app['appkey']
            url = 'https://api.ai.qq.com/fcgi-bin/aai/aai_tts'
            time_s = int(time.time())
            m = hashlib.md5()
            m.update(str(time_s).encode("utf8"))
            nonce_s = m.hexdigest()
            nonce_s = nonce_s[0:random.randint(1, 31)]
            params = {'app_id': appid,
                      'speaker': mode,
                      'format': '2',
                      'volume': '0',
                      'speed': speed*2,
                      'text': text,
                      'aht': '0',
                      'apc': '58',
                      'time_stamp': time_s,
                      'nonce_str': nonce_s,
                      'sign': ''
                      }
            params['sign'] = getReqSign(params, appkey)
            s = urlencode(params)
            res = urlopen(url, s.encode()).read().decode()
            res_dict = eval(res)
            if res_dict['ret'] == 0:
                res_data = res_dict['data']
                res_data_format = res_data['format']
                res_data_speech = res_data['speech']
                res_data_md5sum = res_data['md5sum']
                filepath = path.dirname(__file__)  # 目录
                file = '/wav01.wav'
                base64_data = res_data_speech
                ori_image_data = base64.b64decode(base64_data)
                try:
                    with open('alsovoice.wav', "wb") as f:
                        f.write(ori_image_data)
                    f.close()
                    import wave
                    fr = wave.open('alsovoice.wav', 'rb')
                    secs = fr.getnframes() / fr.getframerate()
                    fr.close()
                    pygame.mixer.init()
                    pygame.mixer.music.load("alsovoice.wav")
                    pygame.mixer.music.play()
                    time.sleep(secs+0.1)
                    return res_dict['ret']
                except:
                    return -1
            else:
                return -1
    def AI_chat(self,text,mode=5):
        if self.availble != True:
            return -2
        else:
            def getReqSign(params, key):
                dict_kl = sorted(params)
                s = ''
                for k in dict_kl:
                    v = params[k]
                    if v != '':
                        v0 = str(quote_plus(str(v)))
                        s = s + k + '=' + v0 + '&'
                s = s + 'app_key=' + key;
                m = hashlib.md5()
                m.update(s.encode("utf8"))
                sign = m.hexdigest()
                sign = sign.upper()
                return sign

            app = json.loads(urlopen("http://www.asunc.cn/ten.txt").read().decode("utf-8"))
            appid = app['appid']
            appkey = app['appkey']
            url = 'https://api.ai.qq.com/fcgi-bin/nlp/nlp_textchat'
            time_s = int(time.time())
            m = hashlib.md5()
            m.update(str(time_s).encode("utf8"))
            nonce_s = m.hexdigest()
            nonce_s = nonce_s[0:random.randint(1, 31)]
            params = {'app_id': appid,
                      'time_stamp': time_s,
                      'nonce_str': nonce_s,
                      'session': '0',
                      'sign': '',
                      'question': text
                      }
            params['sign'] = getReqSign(params, appkey)
            s = urlencode(params)
            res = urlopen(url, s.encode())  # 网络请求
            res_str = res.read().decode()
            res_dict = eval(res_str)
            if res_dict['ret']==0:
                return 0,res_dict['data']['answer']
            else:
                if res_dict['ret'] == 16394:
                    return 404
    def help():
        print(urllib.request.urlopen("http://www.asunc.cn/alsohelp.txt").read().decode('gbk'))
    def pagebrowser(text,title):
        from cefpython3 import cefpython as cef
        import platform
        import sys
        try:
            html = urllib.request.urlopen(text).read().decode("utf-8")
            sys.excepthook = cef.ExceptHook
            cef.Initialize()
            cef.CreateBrowserSync(url=text,window_title=title)
            cef.MessageLoop()
            return 0
        except:
            return -1
    def get_pcsystem(self):
        import platform
        return platform.system()




import urllib.request
class LoadWork:
    def __init__(self,pid):
        self.pid=pid
    def get_likes(self):
        try:
            url="http://code.xueersi.com/api/compilers/"+str(self.pid)+"?id="+str(self.pid)
            headers = {'Content-Type':'application/json'}
            a=requests.get(url=url, headers=headers)
            null,false,list_get,string=0,0,[],''
            p=json.loads(a.text)
            likes=p["data"]["likes"]
            return likes
        except:
            return -1
    def get_user(self):
        try:
            url = "http://code.xueersi.com/api/compilers/" + str(self.pid) + "?id=" + str(self.pid)
            print(url)
            headers = {'Content-Type': 'application/json'}
            a = requests.get(url=url, headers=headers)
            null, false, list_get, string = 0, 0, [], ''
            p = json.loads(a.text)
            return [p["data"]["username"], p["data"]["user_id"]]
        except:
            return -1
    def get_unlikes(self):
        try:
            url="http://code.xueersi.com/api/compilers/"+str(self.pid)+"?id="+str(self.pid)
            headers = {'Content-Type':'application/json'}
            a=requests.get(url=url, headers=headers)
            null,false,list_get,string=0,0,[],''
            p=json.loads(a.text)
            unlikes=p["data"]["unlikes"]
            return unlikes
        except:
            return -1
    def get_description(self):
        try:
            url='https://code.xueersi.com/api/compilers/v2/'+str(self.pid)+'?id='+str(self.pid)
            a=json.loads(urllib.request.urlopen(url).read().decode())
            return a['data']['description']
        except:
            return -1
    def get_codexml(self):
        try:
            url='https://code.xueersi.com/api/compilers/v2/'+str(self.pid)+'?id='+str(self.pid)
            a=json.loads(urllib.request.urlopen(url).read().decode())
            return a['data']['xml']
        except:
            return -1
    def get_name_as_pid(self):
        try:
            url='https://code.xueersi.com/api/compilers/v2/'+str(self.pid)+'?id='+str(self.pid)
            a=json.loads(urllib.request.urlopen(url).read().decode())
            return a['data']['name']
        except:
            return -1

    def is_like(self):
        url='http://code.xueersi.com/api/compilers/v2/'+str(self.pid)+'?id='+str(self.pid)
        data=json.loads(urllib.request.urlopen(url).read().decode())
        like1 = data['data']['likes']
        unlike1 = data['data']['unlikes']
        import time
        time.sleep(1)
        url='http://code.xueersi.com/api/compilers/v2/'+str(self.pid)+'?id='+str(self.pid)
        data=json.loads(urllib.request.urlopen(url).read().decode())
        like2 = data['data']['likes']
        unlike2 = data['data']['unlikes']
        if like2>like1:
            return 0
        elif unlike1>unlike2:
            return -1
        elif like1==like2 and unlike1==unlike2:
            return 1
def help():
    print(urllib.request.urlopen('http://www.asunc.cn/alsoxeshelp.txt').read().decode("gbk"))


import sys
def getCookies():
    cookies = ""
    if len(sys.argv) > 1:
        try:
            cookies = ''
        except:
            pass
    return cookies

def jsonLoads(str):
    try:
        return json.loads(str)
    except:
        return None
import requests
import json


def get_fansnum(id):
    try:
        url = "http://code.xueersi.com/api/space/fans?user_id=" + str(id) + "&page=1&per_page=10"
        num = json.loads(requests.get(url).text)["data"]["total"]
        return num
    except:
        return -1


# coding:utf-8
import time
import zxing
from socket import*
from email.mime.text import MIMEText
from random import*
import smtplib
import requests
import json
import platform
import sys
import urllib.request ,re,os
import time
from re import*
import requests
from urllib.request import*
import json
def baidubaike(text):
    html=urllib.request.urlopen("http://gop.asunc.cn/baike.html").read().decode("utf-8")
    url=html+urllib.parse.quote(text)
    html=urllib.request.urlopen(url).read().decode("utf-8")
    par = '(<meta name="description" content=")(.*?)(">)'
    try:
        data = re.search(par,html).group(2)
        return data
    except:
        return -1
def translate(string):
    data = {'doctype': 'json','type': 'AUTO','i':string}
    url = "http://fanyi.youdao.com/translate"
    r = requests.get(url,params=data)
    result = r.json()
    result = result['translateResult'][0][0]["tgt"]
    return result
def getweather(province,city):
    tf=0
    data = {'doctype': 'json','type': 'AUTO','i':province}
    url = "http://fanyi.youdao.com/translate"
    r = requests.get(url,params=data)
    result = r.json()
    province = result['translateResult'][0][0]["tgt"]
    data = {'doctype': 'json','type': 'AUTO','i':city}
    url = "http://fanyi.youdao.com/translate"
    r = requests.get(url,params=data)
    result = r.json()
    city = result['translateResult'][0][0]["tgt"]
    try:
        wurl="https://tianqi.moji.com/weather/china/"+province+'/'+city
        html = urllib.request.urlopen(wurl).read().decode("utf-8")
        par = '(<meta name="description" content=")(.*?)(">)'
        data = re.search(par, html).group(2)
        data = data.replace(",", "，").replace("。", "，").replace("墨迹天气建议您", "爱搜天气助手建议您")
        return data
    except:
        return -1
import json
import requests
from bs4 import BeautifulSoup
def get_newslist():
    import requests
    try:
        newslist=[]
        url="https://i.news.qq.com/trpc.qqnews_web.pc_base_srv.base_http_proxy/NinjaPageContentSync?pull_urls=news_top_2018"
        data=requests.get(url)
        if data.status_code==200:
            data=json.loads(data.text)
            for i in range(len(data['data'])):
                dict={'title':data['data'][i]['title'],'url':data['data'][i]['url']}
                newslist.append(dict)
            return newslist
    except:
        return -1
def get_newstext(url):
    try:
        html = urllib.request.urlopen(url).read().decode("gbk")
        par = '(<meta name="description" content=")(.*?)(">)'
        try:
            data = re.search(par, html).group(2)
            return data
        except:
            return -1
    except:
        return -1

def printf(text,ts=0.1):
    text=str(text)
    for i in text:
        print(i,end='')
        time.sleep(ts)
def cleardevice():
    import sys
    sys.stdout.write("\033[2J\033[00H")
def pagebrowser(text,title):
    from cefpython3 import cefpython as cef
    import platform
    import sys
    try:
        html = urllib.request.urlopen(text).read().decode("utf-8")
        sys.excepthook = cef.ExceptHook
        cef.Initialize()
        cef.CreateBrowserSync(url=text,window_title=title)
        cef.MessageLoop()
        return 0
    except:
        return -1
def get_pcsystem():
    import platform
    return platform.system()
def find_lib(libname):
    try:
        url='http://127.0.0.1:55820/package/search?name='+libname
        a=json.loads(urlopen(url).read().decode())
        if a['data']['option'][0]['state']=='not_installed':
            return False
        elif a['data']['option'][0]['state']=='installed':
            return True
    except:
        return -1
def download_lib(lib):
    os.system(sys.executable + " -m pip install " + lib + " -i https://pypi.douban.com/simple")


import requests,json
class alsoQQ:
    def __init__(self,qq):
        self.qq=str(qq)
    def get_qqname(self):
        url="https://api.uomg.com/api/qq.info?qq="+self.qq
        qqim=requests.get(url)
        qqim.encoding="gbk"
        string=json.loads(qqim.text)
        return string['name']
    def get_qqimageurl(self):
        url="https://r.qzone.qq.com/fcg-bin/cgi_get_portrait.fcg?g_tk=1518561325&uins="+self.qq
        qqim=requests.get(url)
        qqim.encoding="gbk"
        string=qqim.text
        string=string.replace("portraitCallBack(","")
        string=string.replace(")","")
        return json.loads(string)[self.qq][0]
    def get_qqlvzuan(self):
        url="https://api.uomg.com/api/qq.info?qq="+self.qq
        qqim=requests.get(url)
        qqim.encoding="gbk"
        string=qqim.text
        return json.loads(string)['lvzuan']


from distutils.core import setup #如果没有需要先安装
setup(name='alsolib',  #打包后的包文件名
      version='1.2.20201019',  #版本
      description='爱搜库1.2.20201019，请使用python原版下载',
      author='asunc',
      author_email='asunc@asunc.cn',
      url='http://asunc.cn',
      py_modules=['alsolib\\alsoapi','alsolib\\alsolib','alsolib\\alsoxes',"alsolib\\alsoqq"],  #与前面的新建文件名一致
)